@@ -33,6 +33,9 @@ def find(query, string, split=' ', granularity=1, format='string', threads=2):
 def info():
     print('\n---')
     print('    ^ ^          Description:        Python library for readable regex.')
-    print('("\(-_-)/")      Version:            0.0.6') 
+    print('("\(-_-)/")      Version:            0.0.8') 
     print(' )(  O  )(       Author:             Timo Kats')
     print('((...)(...))     Last updated:       02/07/2023', end='\n---\n\n')
+
+if __name__ == '__main__':
+    print(find('endswith:*num', 'testing 4the test sete5'))
